

-- UPDATE 12.0.0~alpha.1/fix_db_20180311.sql

alter table layout add order_index integer default 0;
update layout l set order_index = (select count(*) from layout where iddb<l.iddb and creator_iddb=l.creator_iddb and l.model_iddb=model_iddb) +1;


-- UPDATE 12.0.0~beta.0/fix_db_20180314.sql

CREATE SEQUENCE plugin_table_iddb_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
  
CREATE TABLE plugin_table
(
  iddb integer NOT NULL DEFAULT nextval('plugin_table_iddb_seq'::regclass),
  hash character varying(255) NOT NULL,
  name character varying(255) NOT NULL,
  version character varying(255) NOT NULL,
  CONSTRAINT plugin_pkey PRIMARY KEY (iddb),
  CONSTRAINT plugin_hash_unique UNIQUE (hash)
);

CREATE TABLE plugin_urls
(
  plugin_iddb integer NOT NULL,
  url character varying(1024) NOT NULL,
  CONSTRAINT plugin_urls_pkey PRIMARY KEY (plugin_iddb, url),
  CONSTRAINT plugin_urls_fk FOREIGN KEY (plugin_iddb)
      REFERENCES public.plugin_table (iddb) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE
);

CREATE SEQUENCE plugin_data_entry_iddb_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;

CREATE TABLE plugin_data_entry
(
  iddb integer NOT NULL DEFAULT nextval('plugin_table_iddb_seq'::regclass),
  plugin_iddb integer NOT NULL,
  user_iddb integer,
  entry_key character varying(1024) NOT NULL,
  entry_value character varying(2048) NOT NULL,
  CONSTRAINT plugin_data_entry_pkey PRIMARY KEY (iddb),
  CONSTRAINT plugin_data_entry_plugin_fk FOREIGN KEY (plugin_iddb)
      REFERENCES public.plugin_table (iddb) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT plugin_data_entry_user_fk FOREIGN KEY (user_iddb)
      REFERENCES public.user_table (iddb) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE
);


-- UPDATE 12.0.0~beta.1/fix_db_20180402.sql

CREATE SEQUENCE user_gui_preferences_iddb_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
  
CREATE TABLE user_gui_preferences
(
  iddb integer NOT NULL DEFAULT nextval('user_gui_preferences_iddb_seq'::regclass),
  key character varying(255) NOT NULL,
  value character varying(255) NOT NULL,
  annotation_schema_iddb integer NOT NULL,
  CONSTRAINT user_gui_preferences_fk FOREIGN KEY (annotation_schema_iddb)
      REFERENCES public.user_annotation_schema_table (iddb) MATCH SIMPLE
      ON UPDATE CASCADE ON DELETE CASCADE,
  CONSTRAINT user_gui_preferences_key_unique UNIQUE (key, annotation_schema_iddb)
);


-- UPDATE 12.0.0~beta.1/fix_db_20180405.sql

alter table node_table add column stoichiometry numeric(9,2) default null;


-- UPDATE 12.0.0~beta.2/fix_db_20180423.sql

-- empty file to force directory to be commited to git repo


-- UPDATE 12.0.0~beta.3/fix_db_20180410.sql

-- empty file to force directory to be commited to git repo


-- UPDATE 12.0.0~beta.3/fix_db_20180411.sql

-- drop data mining structures
drop table datamining_references ;
drop table datamining_connections;
drop table datamining_table;
drop table data_mining_set_table ;
drop sequence datamining_table_iddb_seq;
drop sequence data_mining_set_iddb_seq;

-- change project status from int to string

alter table project_table add column status_string varchar(255) default 'UNKNOWN';
update project_table set status_string = 'PARSING_DATA' where status = 1;
update project_table set status_string = 'ANNOTATING' where status = 2;
update project_table set status_string = 'UPLOADING_TO_DB' where status = 3;
update project_table set status_string = 'EXTENDING_MODEL' where status = 4;
update project_table set status_string = 'GENERATING_IMAGES' where status = 5;
update project_table set status_string = 'CACHING' where status = 6;
update project_table set status_string = 'DONE' where status = 7;
update project_table set status_string = 'FAIL' where status = 8;
update project_table set status_string = 'CACHING_MIRIAM' where status = 9;
update project_table set status_string = 'VALIDATING_MIRIAM' where status = 10;
update project_table set status_string = 'REMOVING' where status = 11;
update project_table set status_string = 'CACHING_CHEMICAL' where status = 12;
update project_table set status_string = 'CACHING_DRUG' where status = 13;
update project_table set status_string = 'CACHING_MI_RNA' where status = 14;
alter table project_table drop column status ;
alter table project_table rename COLUMN status_string to status;

-- remove DATA MINING status
update project_table set status = 'UNKNOWN' where status = 'EXTENDING_MODEL';


-- UPDATE 12.0.0~beta.3/fix_db_20180427.sql

-- alternative implementation of map canvas

alter table project_table add column google_map_license_accept_date timestamp without time zone;
alter table project_table add column map_canvas_type character varying default 'OPEN_LAYERS';


-- UPDATE 12.0.0~beta.3/fix_db_20180530.sql

-- there is problem with privileges with new API
update privilege_table set privilege_class_type_db ='OBJECT_PRIVILEGE' where type = 'LAYOUT_MANAGEMENT';

-- UPDATE 12.0.0~beta.4/fix_db_20180607.sql

-- empty file to force directory to be commited to git repo


-- UPDATE 12.0.0~beta.5/fix_db_20180608.sql

-- empty file to force directory to be commited to git repo


-- UPDATE 12.0.0~beta.6/fix_db_20180628.sql

-- empty file to force directory to be commited to git repo


-- UPDATE 12.0.0~beta.7/fix_db_20180705.sql

-- empty file to force directory to be commited to git repo


-- UPDATE 12.0.0/fix_db_20180716.sql

-- empty file to force directory to be commited to git repo


-- UPDATE 12.0.1/fix_db_20180723.sql

-- issue #461 - duplicates in reaction ids resolved
update reaction_table r set  idreaction=concat(r.idreaction,'_',r.iddb) from (select idreaction, model_iddb from reaction_table group by idreaction, model_iddb having count(*)>1) t where r.idreaction=t.idreaction and r.model_iddb=t.model_iddb;


-- UPDATE 12.0.2/fix_db_20180731.sql

-- issue #461 - duplicates in reaction ids resolved
update reaction_table r set  idreaction=concat(r.idreaction,'_',r.iddb) from (select idreaction, model_iddb from reaction_table group by idreaction, model_iddb having count(*)>1) t where r.idreaction=t.idreaction and r.model_iddb=t.model_iddb;
